@@ -27,7 +27,7 @@ class GsClient(AbstractClient):
 
 
     def BackUpAndroidInstanceToStorage(self, request):
-        """备份云手机到指定存储
+        """备份云手机数据到指定存储，支持 COS 和兼容 AWS S3 协议的对象存储服务。如果是备份到 COS 时，会使用公网流量，授权 COS bucket 请在控制台中操作。
 
         :param request: Request instance for BackUpAndroidInstanceToStorage.
         :type request: :class:`tencentcloud.gs.v20191118.models.BackUpAndroidInstanceToStorageRequest`
@@ -49,6 +49,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CleanAndroidInstancesAppData(self, request):
+        """批量清理安卓实例应用数据
+
+        :param request: Request instance for CleanAndroidInstancesAppData.
+        :type request: :class:`tencentcloud.gs.v20191118.models.CleanAndroidInstancesAppDataRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.CleanAndroidInstancesAppDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CleanAndroidInstancesAppData", params, headers=headers)
+            response = json.loads(body)
+            model = models.CleanAndroidInstancesAppDataResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ConnectAndroidInstance(self, request):
         """连接安卓实例
 
@@ -74,7 +97,7 @@ class GsClient(AbstractClient):
 
     def CopyAndroidInstance(self, request):
         """复制安卓实例：
-        1. 排除和包含文件只能指定/data下的文件，不指定时复制整个/data目录
+        1. 排除和包含文件只能指定 /data 下的文件，不指定时复制整个 /data 目录
         2. 源实例和目的实例必须在同一区域
         3. 复制时，源实例和目的实例都会停机，复制完后实例会自动启动
         4. 复制时会产生大量内网流量，请限制并发
@@ -145,8 +168,31 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAndroidInstanceADB(self, request):
+        """创建云手机实例 ADB 连接信息，请将返回结果的 PrivateKey 字段保存为 pem 文件，并将 pem 文件权限设置为 600，再参考返回结果的 ConnectCommand 使用 adb 连接实例。
+
+        :param request: Request instance for CreateAndroidInstanceADB.
+        :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstanceADBRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstanceADBResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAndroidInstanceADB", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAndroidInstanceADBResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAndroidInstanceImage(self, request):
-        """创建安卓实例镜像
+        """使用指定的安卓实例创建镜像，创建镜像时指定的实例会关机，镜像创建完成后实例会自动开机。当镜像的 AndroidInstanceImageState 为 NORMAL 时，镜像创建完成处于可用状态。
 
         :param request: Request instance for CreateAndroidInstanceImage.
         :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstanceImageRequest`
@@ -192,7 +238,7 @@ class GsClient(AbstractClient):
 
 
     def CreateAndroidInstanceSSH(self, request):
-        """创建安卓实例 SSH 连接
+        """创建安卓实例 SSH 连接信息，请将返回结果的 PrivateKey 字段保存为 pem 文件，并将 pem 文件权限设置为 600，再参考返回结果的 ConnectCommand 使用 ssh 连接实例。
 
         :param request: Request instance for CreateAndroidInstanceSSH.
         :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstanceSSHRequest`
@@ -215,7 +261,7 @@ class GsClient(AbstractClient):
 
 
     def CreateAndroidInstanceWebShell(self, request):
-        """创建安卓实例 WebShell 连接
+        """创建安卓实例 WebShell 连接信息，返回的 ConnectUrl 可通过浏览器直接打开访问，链接有效期 1 小时，链接打开后可持续使用。
 
         :param request: Request instance for CreateAndroidInstanceWebShell.
         :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstanceWebShellRequest`
@@ -468,7 +514,7 @@ class GsClient(AbstractClient):
 
 
     def DescribeAndroidInstanceImages(self, request):
-        """查询安卓实例镜像
+        """查询安卓实例镜像信息，当镜像的 AndroidInstanceImageState 为 NORMAL 时，镜像处于可用状态。
 
         :param request: Request instance for DescribeAndroidInstanceImages.
         :type request: :class:`tencentcloud.gs.v20191118.models.DescribeAndroidInstanceImagesRequest`
@@ -605,6 +651,75 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DisableAndroidInstancesApp(self, request):
+        """批量禁用安卓实例应用
+
+        :param request: Request instance for DisableAndroidInstancesApp.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DisableAndroidInstancesAppRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DisableAndroidInstancesAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DisableAndroidInstancesApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.DisableAndroidInstancesAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DistributeFileToAndroidInstances(self, request):
+        """将一个文件批量分发到多个实例，一次接口调用触发一次文件分发，一次文件分发只会从公网下载一次，然后文件会走内网分发到实例列表中的实例。
+
+        :param request: Request instance for DistributeFileToAndroidInstances.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DistributeFileToAndroidInstancesRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DistributeFileToAndroidInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DistributeFileToAndroidInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.DistributeFileToAndroidInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def EnableAndroidInstancesApp(self, request):
+        """批量启用安卓实例应用
+
+        :param request: Request instance for EnableAndroidInstancesApp.
+        :type request: :class:`tencentcloud.gs.v20191118.models.EnableAndroidInstancesAppRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.EnableAndroidInstancesAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EnableAndroidInstancesApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.EnableAndroidInstancesAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ExecuteCommandOnAndroidInstances(self, request):
         """在安卓实例上异步执行命令，命令输出结果如果内容过长会被截断
 
@@ -629,7 +744,7 @@ class GsClient(AbstractClient):
 
 
     def FetchAndroidInstancesLogs(self, request):
-        """批量获取安卓实例日志
+        """批量将实例的 logcat 日志文件上传到您已授权的 COS bucket 中，授权 COS bucket 请在控制台中操作。
 
         :param request: Request instance for FetchAndroidInstancesLogs.
         :type request: :class:`tencentcloud.gs.v20191118.models.FetchAndroidInstancesLogsRequest`
@@ -674,6 +789,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def InstallAndroidInstancesAppWithURL(self, request):
+        """安装安卓实例应用
+
+        :param request: Request instance for InstallAndroidInstancesAppWithURL.
+        :type request: :class:`tencentcloud.gs.v20191118.models.InstallAndroidInstancesAppWithURLRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.InstallAndroidInstancesAppWithURLResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InstallAndroidInstancesAppWithURL", params, headers=headers)
+            response = json.loads(body)
+            model = models.InstallAndroidInstancesAppWithURLResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAndroidApp(self, request):
         """修改安卓应用信息
 
@@ -812,6 +950,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAndroidInstancesProperties(self, request):
+        """批量修改安卓实例属性
+
+        :param request: Request instance for ModifyAndroidInstancesProperties.
+        :type request: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidInstancesPropertiesRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidInstancesPropertiesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAndroidInstancesProperties", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAndroidInstancesPropertiesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAndroidInstancesResolution(self, request):
         """修改安卓实例分辨率。需要注意的是该接口需要重启才能生效。
 
@@ -858,6 +1019,32 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RebootAndroidInstanceHosts(self, request):
+        """重启安卓实例宿主机。请注意：
+
+        - 当前每 15 分钟只能重启一次
+        - 一个宿主机可能有多个云手机实例，重启宿主机会影响运行在上面的所有实例，请确保该宿主机上的所有云手机实例未投入业务使用
+
+        :param request: Request instance for RebootAndroidInstanceHosts.
+        :type request: :class:`tencentcloud.gs.v20191118.models.RebootAndroidInstanceHostsRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.RebootAndroidInstanceHostsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RebootAndroidInstanceHosts", params, headers=headers)
+            response = json.loads(body)
+            model = models.RebootAndroidInstanceHostsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RebootAndroidInstances(self, request):
         """重启安卓实例
 
@@ -928,7 +1115,7 @@ class GsClient(AbstractClient):
 
 
     def RestoreAndroidInstanceFromStorage(self, request):
-        """指定存储还原云手机
+        """使用指定存储数据还原云手机，支持 COS 和兼容 AWS S3 协议的对象存储服务。如果还原数据来自 COS 时，会使用公网流量，授权 COS bucket 请在控制台中操作。
 
         :param request: Request instance for RestoreAndroidInstanceFromStorage.
         :type request: :class:`tencentcloud.gs.v20191118.models.RestoreAndroidInstanceFromStorageRequest`
@@ -1181,7 +1368,7 @@ class GsClient(AbstractClient):
 
 
     def SyncAndroidInstanceImage(self, request):
-        """同步安卓实例镜像
+        """同步安卓实例镜像到其他区域，当镜像的 AndroidInstanceImageState 为 NORMAL 时，镜像已经同步完成处于可用状态。
 
         :param request: Request instance for SyncAndroidInstanceImage.
         :type request: :class:`tencentcloud.gs.v20191118.models.SyncAndroidInstanceImageRequest`
@@ -1273,7 +1460,7 @@ class GsClient(AbstractClient):
 
 
     def UploadFileToAndroidInstances(self, request):
-        """上传文件到安卓实例
+        """将文件下载到指定实例列表的实例上，每个实例都会从公网下载文件。如果您需要将同一个文件分发到多个实例，建议使用 DistributeFileToAndroidInstances 接口减少公网下载的流量。如果您需要将不同的文件下载到不同的实例，可考虑使用 UploadFilesToAndroidInstances 接口批量将不同文件下载到不同的实例。
 
         :param request: Request instance for UploadFileToAndroidInstances.
         :type request: :class:`tencentcloud.gs.v20191118.models.UploadFileToAndroidInstancesRequest`
@@ -1288,6 +1475,29 @@ class GsClient(AbstractClient):
             model = models.UploadFileToAndroidInstancesResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UploadFilesToAndroidInstances(self, request):
+        """批量将不同的文件下载到不同的实例，每个实例下载文件都是从公网下载，建议只用在文件下载使用一次的场景。如果您需要将同一个文件分发到不同实例，建议使用 DistributeFileToAndroidInstances 接口。
+
+        :param request: Request instance for UploadFilesToAndroidInstances.
+        :type request: :class:`tencentcloud.gs.v20191118.models.UploadFilesToAndroidInstancesRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.UploadFilesToAndroidInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UploadFilesToAndroidInstances", params, headers=headers)
+            response = json.loads(body)
+            model = models.UploadFilesToAndroidInstancesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
