@@ -809,6 +809,9 @@ UNSUPPORTEDOPERATION_BANDWIDTHNOTEXPIRED = 'UnsupportedOperation.BandwidthNotExp
 # 该带宽包不支持此操作。
 UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'
 
+# 绑定了防火墙，请先到防火墙页面解绑。
+UNSUPPORTEDOPERATION_BINDCLOUDFIREWALL = 'UnsupportedOperation.BindCloudFirewall'
+
 # 已绑定EIP。
 UNSUPPORTEDOPERATION_BINDEIP = 'UnsupportedOperation.BindEIP'
 
@@ -971,6 +974,9 @@ UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTKOINSTANCEENI = 'UnsupportedOperation.Flo
 # 不支持创建流日志：当前弹性网卡未绑定实例。
 UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTNULLINSTANCEENI = 'UnsupportedOperation.FlowLogsNotSupportNullInstanceEni'
 
+# GUA类型的网段不支持分配给CDC子网。
+UNSUPPORTEDOPERATION_GUANOTSUPPORTALLOCATECDCSUBNET = 'UnsupportedOperation.GUANotSupportAllocateCdcSubnet'
+
 # TGW还没有投放IPv6网段
 UNSUPPORTEDOPERATION_IPV6CIDRNOTDEPLOYED = 'UnsupportedOperation.IPV6CidrNotDeployed'
 
@@ -1133,6 +1139,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.No
 # 不支持创建后付费流量计费类型云联网
 UNSUPPORTEDOPERATION_NOTSUPPORTEDCREATETRAFFICMETERINGTYPECCN = 'UnsupportedOperation.NotSupportedCreateTrafficMeteringTypeCcn'
 
+# 当前VPN网关不支持指定客户端网段类型
+UNSUPPORTEDOPERATION_NOTSUPPORTEDLOCALADDRESSTYPE = 'UnsupportedOperation.NotSupportedLocalAddressType'
+
 # 此地域没有上线出口二资源，请到北京/广州/南京购买。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDPURCHASECENTEREGRESSRESOURCE = 'UnsupportedOperation.NotSupportedPurchaseCenterEgressResource'
 
